@@ -1,13 +1,13 @@
 package Lemonldap::NG::Handler::PSGI::Router;
 
-use 5.10.0;
+use strict;
 use Mouse;
 require Lemonldap::NG::Handler::PSGI::Main;
 
 extends 'Lemonldap::NG::Handler::Lib::PSGI',
   'Lemonldap::NG::Common::PSGI::Router';
 
-our $VERSION = '2.0.3';
+our $VERSION = '2.0.11';
 
 sub init {
     $_[0]->api('Lemonldap::NG::Handler::PSGI::Main');
@@ -137,7 +137,7 @@ L<https://gitlab.ow2.org/lemonldap-ng/lemonldap-ng/issues>
 =head1 DOWNLOAD
 
 Lemonldap::NG is available at
-L<http://forge.objectweb.org/project/showfiles.php?group_id=274>
+L<https://lemonldap-ng.org/download>
 
 =head1 COPYRIGHT AND LICENSE
 
